/**
 * 救助服务
 */

import { systemConfig } from "../config/serverConfig";
import { jyfwPopTableData, jzfwPopTableData, jzfwTableData } from "../data/table/tableData";
import { keyValuePackage, onceYBarChartPackage, stringListPackage, tablePackage } from "../dataPackage/inFrontOut";
import { getKeyValueOut, getOnceYBarChartOut, getStringOut } from "../dataPackage/out";
import { getConfData, getOneChange } from "../dataPackage/public";
import { findImageOrFolderImages, findVideoOrFolderImages, readFileList } from "../dataPackage/tool";


/**
 * 主界面
 * @param req 
 * @param res 
 */
export function getData(req, res) {
    let excelData = jzfwTableData();

    let ret:any = {};

    /**左屏 */
    let jcgkPackageData = keyValuePackage(excelData['基础概况'].dataList);
    ret['jcgk'] = getKeyValueOut('基础概况', jcgkPackageData);

    let dqjzdxlbjrs = keyValuePackage(excelData['当前救助对象类别及人数'].dataList);
    ret['dqjzdxlbjrs'] = getKeyValueOut('当前救助对象类别及人数', dqjzdxlbjrs);

    let jzmqjzdxqkfx = onceYBarChartPackage(excelData['截止目前救助对象情况分析'], '');
    ret['jzmqjzdxqkfx'] = getOnceYBarChartOut('截止目前救助对象情况分析', jzmqjzdxqkfx);

    let xbblPackageData = keyValuePackage(excelData['性别比例'].dataList);
    ret['xbbl'] = getKeyValueOut('性别比例', xbblPackageData);
    
    let nlfbPackageData = keyValuePackage(excelData['年龄分布'].dataList);
    ret['nlfb'] = getKeyValueOut('年龄分布', nlfbPackageData);

    let zdgzrqPackageData = stringListPackage(excelData['重点关注人群'].dataList);
    ret['zdgzrq'] = getStringOut('重点关注人群', zdgzrqPackageData);

    /**中屏 */
    let ztsjPackageData = keyValuePackage(excelData['整体数据'].dataList);
    ret['ztsj'] = getKeyValueOut('整体数据', ztsjPackageData);
    
    let xxbbPackageData = stringListPackage(excelData['信息播报'].dataList);
    ret['xxbb'] = getStringOut('信息播报', xxbbPackageData);

    let fwzyPackageData = keyValuePackage(excelData['服务资源'].dataList);
    ret['fwzy'] = getKeyValueOut('服务资源', fwzyPackageData);

    let tsfwPackageData = stringListPackage(excelData['特色服务'].dataList);
    ret['tsfw'] = getStringOut('特色服务', tsfwPackageData);

    let yzxjzfwPackageData = keyValuePackage(excelData['援助型救助服务'].dataList);
    let yzxjzfwData = [];
    yzxjzfwPackageData.forEach( info => {
        let {key, value} = info;
        let imgData = readFileList(`img/特色服务/援助型救助服务/${key}/`, [], "jpg");
        yzxjzfwData.push({key, value, img:imgData});
    })
    ret['yzxjzfw'] = {title:"援助型救助服务", dataList:yzxjzfwData};

    let pbxjzfwPackageData = keyValuePackage(excelData['陪伴型救助服务'].dataList);
    let pbxjzfwData = [];
    pbxjzfwPackageData.forEach( info => {
        let {key, value} = info;
        let imgData = readFileList(`img/特色服务/陪伴型救助服务/${key}/`, [], "jpg");
        pbxjzfwData.push({key, value, img:imgData});
    })
    ret['pbxjzfw'] = {title:'陪伴型救助服务', dataList:pbxjzfwData};

    let czxjzfwPackageData = keyValuePackage(excelData['成长型救助服务'].dataList);
    let czxjzfwData = [];
    czxjzfwPackageData.forEach( info => {
        let {key, value} = info;
        let imgData = readFileList(`img/特色服务/成长型救助服务/${key}/`, [], "jpg");
        czxjzfwData.push({key, value, img:imgData});
    })
    ret['czxjzfw'] = {title:'成长型救助服务', dataList:czxjzfwData};


    /**右屏 */
    let sffwdxlbPackageData = keyValuePackage(excelData['随访服务对象类别'].dataList);
    ret['sffwdxlb'] = getKeyValueOut('随访服务对象类别', sffwdxlbPackageData);

    let sfdxlbsjjzsj = stringListPackage(excelData['随访对象类别数据截止时间'].dataList);
    ret['sfdxlbsjjzsj'] = getStringOut('随访对象类别数据截止时间', sfdxlbsjjzsj);

    let sffwnrPackageData = keyValuePackage(excelData['随访服务内容'].dataList);
    ret['sffwnr'] = getKeyValueOut('随访服务内容', sffwnrPackageData);

    let sfnrsjjzsjPackageData = stringListPackage(excelData['随访内容数据截止时间'].dataList);
    ret['sfnrsjjzsj'] = getStringOut('随访内容数据截止时间', sfnrsjjzsjPackageData);

    let sffwnrzbPackageData = keyValuePackage(excelData['随访服务内容占比'].dataList);
    ret['sffwnrzb'] = getKeyValueOut('随访服务内容占比', sffwnrzbPackageData);

    let jzhdTableList = tablePackage(excelData['救助活动'].headerList[0], excelData['救助活动'].bodyList);
    ret['jzhd'] = {title:'救助活动', dataList:jzhdTableList};

    let tshdTableList = tablePackage(excelData['特色活动'].headerList[0], excelData['特色活动'].bodyList);
    let tshdData = {titleList:tshdTableList.titleList, dataList:[]};
    tshdTableList.dataList.forEach( info => {
        let imgName = `${systemConfig.ipUrl}活动图片/${info.A}`;
        info.A = imgName;
        tshdData.dataList.push(info);
    })
    ret['tshd'] = {title:'特色活动', dataList:tshdData};

    res.send(ret);
}


/**
 * 救助服务弹窗
 * @param req 
 * @param res 
 */
export function getPopData(req, res) {
    let name = req.query.name || "滴水湖馨苑二居委";
    let ret:any = {};

    let jyfwExcelData = jyfwPopTableData();
    let excelData = jzfwPopTableData();
     
    let jzfwDataList = excelData["村居委数据采集汇总"].dataList;

    let jzfwNewConf = ["名称", "图片视频类型", "政策已覆盖对象人数", "政策找人对象人数", "低保人员", "低保边缘", "重残无业", "特困供养", "刚性支出困难家庭", "政策找人对象"];
    let jzfwData = getOneChange(excelData["村居委数据采集汇总"].titleList, jzfwNewConf, jzfwDataList, name, "mc");

    //居委名称、居委图片基础数据
    let nameConf = ["名称", "图片视频类型"];
    let nameData = getConfData(nameConf, jzfwData);
    // let imgData = `${systemConfig.ipUrl}村居委/${name}.jpg`;
    let imgData = [];
    if (nameData[1].value == "图片") imgData = findImageOrFolderImages(name, `img/村居委/`);
    else imgData = findVideoOrFolderImages(name, `img/村居委/`);
    nameData.push({key:"地址", value:imgData});
    ret["nameData"] = {title:"图片数据", dataList:nameData};

    //居委概括
    let jwgkConf = ["政策已覆盖对象人数", "政策找人对象人数"];
    let jwgkData = getConfData(jwgkConf, jzfwData);
    ret["jwgk"] = {title:"居委概括", dataList:jwgkData};

    //社区救助顾问信息
    let jyfwDataList = jyfwExcelData["村居委数据采集汇总"].dataList;

    let jyfwNewConf = ["名称", "就业年龄段户籍人数", "无业人数", "失业人数", "图片视频类型", "姓名", "服务年限", "服务电话", "工作格言", "保障员所获荣誉"];
    let jyfwData = getOneChange(jyfwExcelData["村居委数据采集汇总"].titleList, jyfwNewConf, jyfwDataList, name, "mc");

    let jybzyConf = ["姓名", "服务年限", "服务电话", "工作格言", "保障员所获荣誉"];
    let jybzyData = getConfData(jybzyConf, jyfwData);
    
    let jybzy = jybzyData;
    let bzyImg = "";
    jybzyData.forEach( info => {
        let {key, value} = info;
        if (key == "姓名") {
            bzyImg = `${systemConfig.ipUrl}保障员/${value}.jpg`;
            jybzy.push({key:"照片", value:bzyImg});
        }
    })
    ret["jybzy"] = {title:"就业保障员", dataList:jybzy};

    //重点关注人群
    let zdgzrqConf = ["低保人员", "低保边缘", "重残无业", "特困供养", "刚性支出困难家庭", "政策找人对象"];
    let zdgzrqData = getConfData(zdgzrqConf, jzfwData);
    ret["zdgzrq"] = {title:"重点关注人群", dataList:zdgzrqData};

    res.send(ret);
}


