/**
 * 查询机
 */

import { ERRORENUM } from "../config/errorEnum";
import { systemConfig } from "../config/serverConfig";
import { employmentTableData } from "../data/table/queryMachine";
import { BizError } from "../util/bizError";
import { get } from "../util/request";
const fs = require("fs");
const path = require('path');

/**
 * 岗位在线（区网数据）
 * @param req 
 * @param res 
 */
 export async function getQWScreen(req, res) {
    let ret:any = {};

    let qwPostList = await get(systemConfig.qwUrl);
    
    if(!qwPostList || !qwPostList['body'] || !qwPostList['body']['PostList']) throw new BizError(ERRORENUM.接口数据获取失败, `区网岗位信息列表获取接口失败`);
    let qwJobInfo = qwPostList['body']['PostList'];

    let qwJobData = [];
    qwJobInfo.forEach( info => {
        for(let key in info) {
            if(key == "View_PostDescriptionA" || key == "View_PostDescriptionB") {
                let newStr = info[key].split("\r\n");
                info[key] = newStr;
            }
        }
        qwJobData.push(info);
    })

    let qwJobInformation = {dataList: qwJobData, total: qwPostList['body']['TotalRecord']};
    
    ret['qwJobInformation'] = qwJobInformation;
    
    res.send(ret);
}


/**
 * 岗位信息
 * @param req 
 * @param res 
 */
 export function getLargeScreen(req, res) {
    let tableData = employmentTableData();

    let ret:any = {};

    let oldConf = ['gsmc', 'zprs', 'gzdd', 'lggw', 'tyjryx'];
    let newConf = ['公司名称', '招聘人数', '工作地点', '零工岗位', '退役军人'];

    tableData['南汇新城镇招聘岗位信息'].dataList.sort((a, b) => {
        return Date.parse(b.fbsj) - Date.parse(a.fbsj);
    })

    let jobTableData = [];
    tableData['南汇新城镇招聘岗位信息'].dataList.forEach(info => {
        let dataList = [];
        for (let i = 0; i < oldConf.length; i++) {
            let value = "";
            if (info[oldConf[i]]) value = info[oldConf[i]]
            dataList.push({key:newConf[i], value});
        }

        jobTableData.push({id:info.id, title:info.gwmc, dataList});
    })

    // let jobTableDataList = change(oldConf, newConf, tableData['南汇新城镇招聘岗位信息'].dataList, '', 'gwmc');
    // let jobTableDataList = change(oldConf, newConf, tableData['南汇新城镇招聘岗位信息'].dataList, '', '');

    // let jobTableData = [];
    // jobTableDataList.forEach(info => {
    //     let {name, list} = info;
    //     let recruit = {key:'招聘人数', value:0};
    //     let lggw = {key:'零工岗位', value:''};``
    //     let tyjr = {key:'退役军人', value:''};
    //     for (let i = 0; i < list.length; i++) {
    //         //招聘人数
    //         if(isNaN(list[i][1].value)) {
    //             recruit['value'] = list[i][1].value;
    //             break;
    //         }
    //         else recruit['value'] += parseInt(list[i][1].value);
    //         //零工岗位
    //         if(list[i][3].value) {
    //             lggw['value'] = list[i][4].value;
    //         }
    //         //退役军人
    //         if(list[i][4].value) {
    //             tyjr['value'] = list[i][4].value;
    //         }
    //     }
        
    //     let dataList = [list[0][0], recruit, list[0][2], lggw, tyjr];
    //     jobTableData.push({title:list[0][5], dataList});
    // })

    // console.log(jobTableData);

    ret['jobInformation'] = jobTableData;

    

    res.send(ret);
}


/**
 * 岗位详情
 * @param req 
 * @param res 
 */
 export function getJobDetailed(req, res) {
    let id = req.query.id;
    if (!id) throw new BizError(ERRORENUM.参数错误, `缺失竖屏岗位详情===>id参数`);
    let tableData = employmentTableData();

    let ret:any = {};

    let oldConf = ['gwmc', 'gwyq', 'gwzz', 'xzdy', 'gzdd', 'lggw', 'tyjryx'];
    let newConf = ['招聘岗位', '岗位要求', '岗位职责', '工资待遇', '工作地点', '零工岗位', '退役军人优先'];
    let jobDetailed = change(oldConf, newConf, tableData['南汇新城镇招聘岗位信息'].dataList, id, 'id');

    ret['jobDetailed'] = jobDetailed;

    res.send(ret);
}


/**
 * 政策快查
 * @param req 
 * @param res 
 * 如果目录文件只有两级，two返回空数组two:[],three返回文件名称和文件地址，如果目录文件有三级，three作为数组对象放在two里面，并且two需要在title返回对应目录名称
 * @returns policy:[{
 *  name:"目录1", 
 *  list:[{fileName:"文件名称", filePath:"文件地址(已拼接ip)"}],
 * }]
 */
 export function getPolicy(req, res) {
    let ret:any = {};

    let filesList = [];
    //对应pdf文件内三个一级目录
    let policyConf = ["创业", "培训", "就业"];
    
    for (let i = 0; i < policyConf.length; i++) { 
        filesList.push({name:policyConf[i], list:[]});
        getFilesWithLevels(`pdf/${policyConf[i]}/`, "pdf", filesList[i]);
    }

    ret['policy'] = filesList;

    res.send(ret);
}


/**
 * 获取pdf文件夹下所有政策文件
 * @param dirPath 文件地址
 * @param ext 文件类型
 * @param fileLevels 存放数据数组
 * @returns 
 */
function getFilesWithLevels(dirPath, ext = 'pdf', fileLevels) {  
    const files = fs.readdirSync(dirPath);  
    
    files.forEach(file => {  
        const fullPath = path.join(dirPath, file);  
        let filePath = `${dirPath}${file}`;
        const stat = fs.statSync(fullPath);  

        if (stat.isDirectory()) {  
            // 如果是目录，则递归调用自身  
            getFilesWithLevels(`${filePath}/`, ext, fileLevels);  
        } else if (path.extname(file).toLowerCase() === `.${ext}`) {  
            // 如果是文件，则确定其层级并添加到fileLevels中  
            const relativePath = path.relative(process.cwd(), filePath);  
            const levels = relativePath.split(path.sep).filter(Boolean).length - 1; // 排除当前目录（process.cwd()）  
            let lastIndex = file.lastIndexOf('.');
            let fileName = file.substring(0, lastIndex);

            /**截取掉地址前面的pdf/ */
            let pdfToRemove = filePath.replace(new RegExp(`^pdf/`), "");
            let fileStr = `${systemConfig.ipUrl}${pdfToRemove}`;
            fileLevels.list.push({fileName, fullPath:fileStr});

        }  
    });  
    
    return fileLevels;  
} 


/**
 * 修改数据结构
 * @param oldConf 表格数据原本的key
 * @param newConf 需要修改成的中文key 
 * @param dataList 表格数据
 * @param name 匹配数据的参数
 * @param subName 参数匹配数据的字段key
 * @returns 
 */
export function change(oldConf, newConf, dataList, name, subName){
    let reg = new RegExp(name);
    
    let data = {};
    dataList.forEach((subList) => {
        if (subName == "id") {
            if (name == subList[subName]) {
                if (!data[subList['gsmc']]) data[subList['gsmc']] = [];
                let gsList = [];
                for(let i = 0; i < newConf.length; i++) {
                    if (newConf[i] == "招聘进度") {
                        gsList.push({
                            key: newConf[i],
                            value: '招聘中'
                        })
                    } if (newConf[i] == "岗位职责" || newConf[i] == "岗位要求") {
                        let newStr = [];
                        if(subList[oldConf[i]]) newStr = subList[oldConf[i]].split("\r\n");
                        gsList.push({
                            key: newConf[i],
                            value: newStr
                        })
                    }
                    else {
                        gsList.push({
                            key: newConf[i],
                            value: subList[oldConf[i]] || ""
                        })
                    }
                }
                data[subList['gsmc']].push(gsList);
            }
        } else if (reg.test(subList[subName])) {
            if (!data[subList['gsmc']]) data[subList['gsmc']] = [];
            let gsList = [];
            for(let i = 0; i < newConf.length; i++) {
                if (newConf[i] == "招聘进度") {
                    gsList.push({
                        key: newConf[i],
                        value: '招聘中'
                    })
                } if (newConf[i] == "岗位职责" || newConf[i] == "岗位要求") {
                    let newStr = [];
                    if(subList[oldConf[i]]) newStr = subList[oldConf[i]].split("\r\n");
                    gsList.push({
                        key: newConf[i],
                        value: newStr
                    })
                }
                 else {
                    gsList.push({
                        key: newConf[i],
                        value: subList[oldConf[i]] || ""
                    })
                }
            }
            data[subList['gsmc']].push(gsList);
        }
    });

    let result = [];
    for (let key in data) {
        result.push({
            name: key,
            list: data[key]
        })
    }

    return result;
}


