/**
 * 大屏 数据化管理平台
 */

import { planarArrDecollateForIndex, planarArrDeconstruct, planarArrForObjectList } from "../../dataPackage/planaryArrayAnalysis";
import { getRandomInt } from "../../dataPackage/tool";
import { onceSheetBecomeOfblockData } from "../../util/analysisExcel";
const XLSX = require('xlsx');
const path = require('path');

function packageDataProcess(blockDataList, titltListConfig, keyValueOrTitleList, barChartList, stringList, decollatePlanarList) {
    let result = {};

    for (let i = 0; i < blockDataList.length; i++) {
        let {blockData, blockTitle} = blockDataList[i];
        if (keyValueOrTitleList.indexOf(blockTitle) > -1) {
            let titleList = titltListConfig[blockTitle] || [];
            result[blockTitle] = planarArrForObjectList(blockData, 0, titleList);
        }
        else if (barChartList.indexOf(blockTitle) > -1) {
            result[blockTitle] = planarArrDeconstruct(blockData);
        }
        else if (stringList.indexOf(blockTitle) > -1) result[blockTitle] = planarArrForObjectList(blockData);
        else if (decollatePlanarList.indexOf(blockTitle) > -1) result[blockTitle] = planarArrDecollateForIndex(blockData);
    }

    return result;
}


/**
 * 就业地图
 * @returns 
 */
export function mapJyTableData() {
    let blockDataList = onceSheetBecomeOfblockData('大屏/地图.xlsx', '就业地图数据'); //excel表名 sheet名称

    let keyValueOrTitleList = ['地图坐标点位']; //适配 饼图 键值以及需要多个Key的
    let barChartList = []; //适配 柱状图 折线图
    let stringList = [];
    let decollatePlanarList = []; //适配 表格
    let titleListConfig = {};

    let result = packageDataProcess(blockDataList, titleListConfig, keyValueOrTitleList, barChartList, stringList, decollatePlanarList);
    return result;
}


/**
 * 救助地图
 * @returns 
 */
 export function mapJzTableData() {
    let blockDataList = onceSheetBecomeOfblockData('大屏/地图.xlsx', '救助地图数据'); //excel表名 sheet名称

    let keyValueOrTitleList = ['地图坐标点位']; //适配 饼图 键值以及需要多个Key的
    let barChartList = []; //适配 柱状图 折线图
    let stringList = [];
    let decollatePlanarList = []; //适配 表格
    let titleListConfig = {};

    let result = packageDataProcess(blockDataList, titleListConfig, keyValueOrTitleList, barChartList, stringList, decollatePlanarList);
    return result;
}


/**
 * 就业服务 【主界面】
 */
export function jyfwTableData() {
    let blockDataList = onceSheetBecomeOfblockData('大屏/就业大屏.xlsx', '主界面');

    let keyValueOrTitleList = ['基础概况', '性别分析', '年龄分布', '学历分布', '失无业人员情况分析', '失无业人员性别比例', '失无业人员年龄分布', 
    '整体数据', '信息播报', '服务资源', '湖畔汇·享业苑', 
    '就业服务', '创业服务'];
    let barChartList = ['失无业情况趋势', '南汇新城镇就创业补贴发放情况', '失无业人员服务成效']; //适配 柱状图 折线图
    let stringList = [];
    let decollatePlanarList = ['培训服务', '零工岗位']; //适配 表格
    let titleListConfig = [];

    let result = packageDataProcess(blockDataList, titleListConfig, keyValueOrTitleList, barChartList, stringList, decollatePlanarList);
    return result;
}


/**
 * 就业服务 【村居委弹窗】
 */
export function jyfwPopTableData() {
    let blockDataList = onceSheetBecomeOfblockData('大屏/就业大屏.xlsx', '村居委数据');

    let keyValueOrTitleList = ["村居委数据采集汇总"];
    let barChartList = []; //适配 柱状图 折线图
    let stringList = [];
    let decollatePlanarList = [];
    let titleListConfig = [];

    let result = packageDataProcess(blockDataList, titleListConfig, keyValueOrTitleList, barChartList, stringList, decollatePlanarList);
    return result;
}


/**
 * 救助服务 【主界面】
 */
export function jzfwTableData() {
    let blockDataList = onceSheetBecomeOfblockData('大屏/救助大屏.xlsx', '主界面');

    let keyValueOrTitleList = ["基础概况", "当前救助对象类别及人数", "性别比例", "年龄分布", "重点关注人群", 
    "整体数据", "信息播报", "服务资源", "特色服务", "援助型救助服务", "陪伴型救助服务", "成长型救助服务", 
    "随访服务对象类别", "随访对象类别数据截止时间", "随访服务内容", "随访内容数据截止时间", "随访服务内容占比"];
    let barChartList = ["截止目前救助对象情况分析"]; //适配 柱状图 折线图
    let stringList = [];
    let decollatePlanarList = ["救助活动", "特色活动"]; //适配表格
    let titleListConfig = [];

    let result = packageDataProcess(blockDataList, titleListConfig, keyValueOrTitleList, barChartList, stringList, decollatePlanarList);
    return result;
}


/**
 * 救助服务 【村居委弹窗】
 */
export function jzfwPopTableData() {
    let blockDataList = onceSheetBecomeOfblockData('大屏/救助大屏.xlsx', '村居委弹窗');

    let keyValueOrTitleList = ['村居委数据采集汇总'];
    let barChartList = []; //适配 柱状图 折线图
    let stringList = [];
    let decollatePlanarList = []; //适配表格
    let titleListConfig = [];

    let result = packageDataProcess(blockDataList, titleListConfig, keyValueOrTitleList, barChartList, stringList, decollatePlanarList);
    return result;
}


/**
 * 区网重点关注人群
 */
export function qwZdgzrqTableData(zdgzrqConf, name) {
    if (name == "东岸涟城居委") name = "东岸涟城一居委"
    else if (name == "临港家园居委") name = "临港家园社区居委会"
    else if (name == "农场居委") name = "农场社区居委会"
    else if (name == "港口居委") name = "港口居委会"
    else if (name == "果园居委") name = "果园居委会"
    else if (name == "新芦居委") name = "新芦社区居委会"
    else if (name == "海尚居委") name = "海尚社区居委会"
    else if (name == "海芦居委") name = "海芦社区居委会"
    else if (name == "海汇居委") name = "海汇社区居委会"
    let zdgzrqData = {};
    for (let i = 0; i < zdgzrqConf.length; i++) {
        let excelName = zdgzrqConf[i];
        let excelPath = path.join(__dirname.substring(0,__dirname.indexOf("out")), "res/区网", `${excelName}.xls` );
        let excelData = readExcel(excelPath);
    
        let focusGroupsTitle = excelData[0];
        let focusGroups = excelData.slice(1);
        
        let cjwFocusGroupsTitle = ["序号", "姓名", "性别", "年龄", "学历", "身份证号", "户籍地址", "目前状况", "服务次数"];
        let cjwFocusGroups = getCjwData(focusGroups, name);

        let tableData = {
            titleList: cjwFocusGroupsTitle,
            dataList: cjwFocusGroups,
        };

        zdgzrqData[excelName] = tableData;
    }

    return zdgzrqData;
}




/**
 * 读取excel文件数据
 * @param filePath 
 * @returns 
 */
function readExcel(filePath) {
    let workbook = XLSX.readFile(filePath);

    //获取第一个工作表
    let firstSheetName = workbook.SheetNames[0];
    let worksheet = workbook.Sheets[firstSheetName];
    let jsonData = XLSX.utils.sheet_to_json(worksheet, {header: 1});

    return jsonData;
}


/**
 * 获取对应村居委数据
 * @param data 
 * @param name 
 * @returns 
 */
function getCjwData(data, name) {
    let reg = new RegExp(name);

    let result = [];
    let index = 1;
    for (let i = 0; i < data.length; i++) {
        let count = 0;
        let info = data[i];
        // 匹配数组下标6（村居委名称）
        if (reg.test(info[6])) {
            let xm = info[1] ? info[1].slice(0, 1) + "**" : "";
            let sfz = info[3] ? info[3].slice(0, 14) + "****" : "";
            let dz = info[8] ? info[8].slice(0, info[8].length-4) + "****" : "";
            let fwcs = getRandomInt(1, 5);
            result.push(
                [
                    //序号，姓名，性别，年龄，学历，身份证号，户籍地址，目前状况，服务次数
                    index, xm, info[2], info[4], info[10], sfz, dz, info[7], fwcs
                ]
            );
            index++;
        }
    }

    return result;
}

