import { systemConfig } from "../config/serverConfig";

const fs = require("fs");
const path = require('path');


/**
 * separateDataAndUint 截取字符串中的单位
 * @param str 待处理字符串
 * @returns {dataNumber:数据, dataUnit:单位}
 */
 export function separateDataAndUint(str) {
    str = `${str}`;
    if (!str) return {dataNum:0, dataUnit:""};
    let dataNum = parseFloat(str.replace(/[\u4E00-\u9FA5a-zA-Z]+/,""));
    let dataUnit = str.replace(/^(-)?\d+(\.\d+)?/, "");
    return {dataNum, dataUnit};
}

/**
 * unifiedMaxAndMinValueAndStep 求最大最小值以及间隙 
 * @param max 最大
 * @param min 最小
 * @param count 分多少份 默认5
 * @returns {maxNumber:向上留值最大, minNumber:向下留值最小, stepNumber:间隔};
 */
 export function unifiedMaxAndMinValueAndStep(max, min, count=5) {
    let maxNumber = Math.ceil(max);
    let minNumber = Math.floor(min);

    function getNumberInLength(length) {
        let lengthCount = 1;
        for (let i = 1; i < length; i++) {
            lengthCount = lengthCount * 10;
        }
        return lengthCount;
    }

    let maxNumberLength = getNumberInLength(`${maxNumber}`.length);
    let minNumberLength = getNumberInLength(`${minNumber}`.length);
    
    if (maxNumber <= 10 && maxNumber > 0) maxNumber = 10;
    else maxNumber = Math.ceil(maxNumber / maxNumberLength) * maxNumberLength;
    minNumber =  Math.floor(minNumber / minNumberLength) * minNumberLength;
    
    let stepNumber = Math.ceil((maxNumber - minNumber) / count);

    return {maxNumber, minNumber, stepNumber};
}



/**
 * 获取查询机园区图片
 * @param dirPath 文件地址
 * @param filesList 存放数据数组
 * @param ext 文件类型
 * @returns 
 */
 export function readFileList(dirPath, filesList, ext) {
    let files = fs.readdirSync(dirPath);
    // console.log(files);
    for (let i = 0; i < files.length; i++) { 
        let itm = files[i];
        let stat = fs.statSync(dirPath + itm);
        if (stat.isDirectory()) { //判断文件是否是目录
            //递归读取文件
            readFileList(dirPath + itm + "/", filesList, ext)
        } else if (path.extname(itm).toLowerCase() === `.${ext}`) {
            let filePath = `${dirPath}${itm}`;
            /**截取掉地址前面的pdf/ */
            let pdfToRemove = filePath.replace(new RegExp(`^img/`), "");
            let fileStr = `${systemConfig.ipUrl}${pdfToRemove}`;
            filesList.push(fileStr);
        }
    }

    return filesList;
}



/**
 * 随机服务次数 1-5
 * @param min 
 * @param max 
 * @returns 
 */
 export function getRandomInt(min, max) {  
    min = Math.ceil(min);  
    max = Math.floor(max);  
    return Math.floor(Math.random() * (max - min + 1)) + min;  
} 


/**
 * 根据传入名称查找图片或文件夹内的图片
 * @param name 
 * @param imgDirPath 
 * @returns 
 */  
export function findImageOrFolderImages(name, imgDirPath) {  
    // 完整路径到可能存在的图片文件  
    const imgFilePath = path.join(imgDirPath, `${name}.jpg`); // 假设只查找.jpg，可以根据需要添加其他扩展名 

    // 检查图片文件是否存在  
    if(fs.existsSync(imgFilePath)) {
        // 图片文件存在，返回图片路径 
        /**截取掉地址前面的pdf/ */
        let pdfToRemove = imgFilePath.replace(/\\/g, '/').replace(new RegExp(`^img/`), "");
        let fileStr = [`${systemConfig.ipUrl}${pdfToRemove}`];
        return fileStr;  
    } else {
        let imageFiles = readFileList(`${imgDirPath}${name}/`, [], "jpg");
        return imageFiles.length > 0 ? imageFiles : [];
    }
}  



/**
 * 根据传入名称查找视频或文件夹内的视频
 * @param name 
 * @param imgDirPath 
 * @returns 
 */  
 export function findVideoOrFolderImages(name, imgDirPath) {  
    // 完整路径到可能存在的图片文件  
    const imgFilePath = path.join(imgDirPath, `${name}.mp4`); // 假设只查找.jpg，可以根据需要添加其他扩展名 

    // 检查图片文件是否存在  
    if(fs.existsSync(imgFilePath)) {
        // 图片文件存在，返回图片路径 
        /**截取掉地址前面的pdf/ */
        let pdfToRemove = imgFilePath.replace(/\\/g, '/').replace(new RegExp(`^img/`), "");
        let fileStr = [`${systemConfig.ipUrl}${pdfToRemove}`];
        return fileStr;  
    } else {
        let imageFiles = readFileList(`${imgDirPath}${name}/`, [], "mp4");
        return imageFiles.length > 0 ? imageFiles : [];
    }
}  



// 辅助函数，检查文件扩展名是否为图片  
function isImageFile(fileName) {  
    const ext = path.extname(fileName).toLowerCase();  
    return ['.jpg', '.jpeg', '.png', '.gif'].includes(ext);  
}  






